diff PalanthirServer/FromDcmtkBridge.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 33d67e1ab173
children 293038baf8f1
line wrap: on
line diff
--- a/PalanthirServer/FromDcmtkBridge.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/PalanthirServer/FromDcmtkBridge.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -22,7 +22,7 @@
 
 #include "ToDcmtkBridge.h"
 #include "DicomIntegerPixelAccessor.h"
-#include "../Core/PalantirException.h"
+#include "../Core/PalanthirException.h"
 #include "../Core/PngWriter.h"
 #include "../Core/DicomFormat/DicomString.h"
 #include "../Core/DicomFormat/DicomNullValue.h"
@@ -45,7 +45,7 @@
 
 #include <boost/math/special_functions/round.hpp>
 
-namespace Palantir
+namespace Palanthir
 {
   void FromDcmtkBridge::Convert(DicomMap& target, DcmDataset& dataset)
   {
@@ -73,7 +73,7 @@
   {
     if (!element.isLeaf())
     {
-      throw PalantirException("Only applicable to leaf elements");
+      throw PalanthirException("Only applicable to leaf elements");
     }
 
     if (element.isaString())
@@ -370,7 +370,7 @@
     DcmFileFormat dicom;
     if (!dicom.loadFile(path.c_str()).good())
     {
-      throw PalantirException(ErrorCode_BadFileFormat);
+      throw PalanthirException(ErrorCode_BadFileFormat);
     }
     else
     {
@@ -471,7 +471,7 @@
       break;
 
     default:
-      throw PalantirException(ErrorCode_NotImplemented);
+      throw PalanthirException(ErrorCode_NotImplemented);
     }
 
     if (accessor.get() == NULL ||
@@ -498,7 +498,7 @@
         break;
 
       default:
-        throw PalantirException(ErrorCode_NotImplemented);
+        throw PalanthirException(ErrorCode_NotImplemented);
       }
     }
   }
@@ -522,7 +522,7 @@
     }
     else
     {
-      throw PalantirException(ErrorCode_BadFileFormat);
+      throw PalanthirException(ErrorCode_BadFileFormat);
     }
   }
 
@@ -553,7 +553,7 @@
     if (entry == NULL)
     {
       dcmDataDict.unlock();
-      throw PalantirException("Unknown DICOM tag");
+      throw PalanthirException("Unknown DICOM tag");
     }
     else
     {
@@ -582,7 +582,7 @@
   {
     if (result.type() != Json::objectValue)
     {
-      throw PalantirException(ErrorCode_BadParameterType);
+      throw PalanthirException(ErrorCode_BadParameterType);
     }
 
     result.clear();
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium